@@ -23,17 +23,17 @@ from aliyunsdkopensearch.endpoint import endpoint_data
 class CreateModelRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'CreateModel','opensearch')
+		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'CreateModel')
 		self.set_uri_pattern('/v4/openapi/app-groups/[appGroupIdentity]/algorithm/models')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_appGroupIdentity(self):
+	def get_appGroupIdentity(self): # String
 		return self.get_path_params().get('appGroupIdentity')
 
-	def set_appGroupIdentity(self,appGroupIdentity):
-		self.add_path_param('appGroupIdentity',appGroupIdentity)
\ No newline at end of file
+	def set_appGroupIdentity(self, appGroupIdentity):  # String
+		self.add_path_param('appGroupIdentity', appGroupIdentity)
