@@ -23,23 +23,22 @@ from aliyunsdkopensearch.endpoint import endpoint_data
 class GetModelProgressRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'GetModelProgress','opensearch')
+		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'GetModelProgress')
 		self.set_uri_pattern('/v4/openapi/app-groups/[appGroupIdentity]/algorithm/models/[modelName]/progress')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_modelName(self):
+	def get_modelName(self): # String
 		return self.get_path_params().get('modelName')
 
-	def set_modelName(self,modelName):
-		self.add_path_param('modelName',modelName)
-
-	def get_appGroupIdentity(self):
+	def set_modelName(self, modelName):  # String
+		self.add_path_param('modelName', modelName)
+	def get_appGroupIdentity(self): # String
 		return self.get_path_params().get('appGroupIdentity')
 
-	def set_appGroupIdentity(self,appGroupIdentity):
-		self.add_path_param('appGroupIdentity',appGroupIdentity)
\ No newline at end of file
+	def set_appGroupIdentity(self, appGroupIdentity):  # String
+		self.add_path_param('appGroupIdentity', appGroupIdentity)
